package VMOMI::DVSPolicy;
use parent 'VMOMI::DynamicData';

use strict;
use warnings;

our @class_ancestors = ( 
    'DynamicData',
);

our @class_members = ( 
    ['autoPreInstallAllowed', 'boolean', 0, 1],
    ['autoUpgradeAllowed', 'boolean', 0, 1],
    ['partialUpgradeAllowed', 'boolean', 0, 1],
);

sub get_class_ancestors {
    return @class_ancestors;
}

sub get_class_members {
    my $class = shift;
    my @super_members = $class->SUPER::get_class_members();
    return (@super_members, @class_members);
}

1;
